.. :changelog:

Release History
---------------

0.1.8
+++++

Internal structure changes. All vendor features should be created under nelsnmp.vendors.

* Implemented Hostinfo check to get vendor and version (for Cisco devices)
* Marked nelsnmp.cisco_oids as deprecated, use nelsnmp.vendors.cisco.oids
* Added sysORTable
* Added oids from CISCO-ENVMON-MIB and CISCO-ENTITY-SENSOR-MIB

0.1.7
+++++

* Made error handling more flexible

0.1.6
+++++

* Added oids from CISCO-CONFIG-COPY-MIB

0.1.5
+++++

* Added ability to set snmp port
* Added cdpCacheDeviceId, cdpCacheDevicePort

0.1.4
+++++

Created changes file
